@@ -1,6 +1,6 @@
 "dataquality"
 
-__version__ = "v0.2.6"
+__version__ = "v0.3.0"
 
 import resource
 
@@ -23,6 +23,7 @@ from dataquality.core.log import (
     set_tagging_schema,
     set_tasks_for_run,
 )
+from dataquality.utils.dq_logger import get_dq_log_file
 
 
 def configure() -> None:
@@ -61,6 +62,7 @@ __all__ = [
     "set_split",
     "log_data_sample",
     "log_dataset",
+    "get_dq_log_file",
 ]
 
 try:
