@@ -5,9 +5,10 @@ from pydantic import UUID4
 
 import dataquality
 from dataquality.clients.api import ApiClient
-from dataquality.core._config import ConfigData, config
+from dataquality.core._config import config
 from dataquality.schemas import RequestType, Route
 from dataquality.schemas.job import JobName
+from dataquality.utils.dq_logger import DQ_LOG_FILE_HOME, upload_dq_log_file
 from dataquality.utils.helpers import check_noop
 from dataquality.utils.thread_pool import ThreadPoolManager
 from dataquality.utils.version import _version_check
@@ -33,6 +34,7 @@ def finish() -> Optional[Dict[str, Any]]:
 
     data_logger.upload()
     data_logger._cleanup()
+    upload_dq_log_file()
 
     body = dict(
         project_id=str(config.current_project_id),
@@ -105,7 +107,9 @@ def _reset_run(project_id: UUID4, run_id: UUID4) -> None:
     )
     # All of the logged user data is to the old run ID, so rename it to the new ID
     os.rename(f"{project_dir}/{old_run_id}", f"{project_dir}/{config.current_run_id}")
-    # Move stdout as well
-    stdout_dir = f"{ConfigData.DEFAULT_GALILEO_CONFIG_DIR}/stdout"
-    os.rename(f"{stdout_dir}/{old_run_id}", f"{stdout_dir}/{config.current_run_id}")
+    # Move std logs as well
+    os.rename(
+        f"{DQ_LOG_FILE_HOME}/{old_run_id}",
+        f"{DQ_LOG_FILE_HOME}/{config.current_run_id}",
+    )
     config.update_file_config()
