@@ -15,6 +15,7 @@ from dataquality.loggers.logger_config.base_logger_config import (
 )
 from dataquality.schemas.split import Split, conform_split
 from dataquality.schemas.task_type import TaskType
+from dataquality.utils.dq_logger import upload_dq_log_file
 
 try:
     from torch import Tensor
@@ -244,4 +245,5 @@ class BaseGalileoLogger:
         """
         # If a currently active thread crashed, check and raise a top level exception
         if cls.logger_config.exception:
+            upload_dq_log_file()
             raise GalileoException(cls.logger_config.exception)
