@@ -11,6 +11,7 @@ class TextMultiLabelLoggerConfig(BaseLoggerConfig):
     observed_num_labels: Optional[List[int]] = None
     tasks: Optional[List[str]] = None
     observed_num_tasks: int = 0
+    binary: bool = False  # For binary multi label
 
     class Config:
         validate_assignment = True
@@ -23,9 +24,12 @@ class TextMultiLabelLoggerConfig(BaseLoggerConfig):
         if labels is not None:
             assert isinstance(labels, List), "Labels must be a list of lists"
             for task_labels in labels:
-                assert isinstance(task_labels, List), "Labels must be a list of lists"
+                assert isinstance(task_labels, List), (
+                    "Labels must be a list of lists. If you are running a binary "
+                    "multi-label case, use `dq.set_tasks_for_run(labels, binary=True)"
+                )
                 if len(task_labels) == 1:
-                    task_labels = [task_labels[0], f"NOT_{task_labels[0]}"]
+                    task_labels = [f"NOT_{task_labels[0]}", task_labels[0]]
                 cleaned_labels.append([str(i) for i in task_labels])
         return cleaned_labels
 
