@@ -12,18 +12,16 @@ from vaex.dataframe import DataFrame
 import dataquality
 from dataquality import config
 from dataquality.clients import objectstore
-from dataquality.core._config import ConfigData
 from dataquality.loggers import BaseGalileoLogger
 from dataquality.schemas.task_type import TaskType
+from dataquality.utils.dq_logger import DQ_LOG_FILE_HOME
 
 DEFAULT_API_URL = "http://localhost:8088"
-DEFAULT_MINIO_URL = "127.0.0.1:9000"
 DEFAULT_PROJECT_ID = UUID("399057bc-b276-4027-a5cf-48893ac45388")
 DEFAULT_RUN_ID = UUID("399057bc-b276-4027-a5cf-48893ac45388")
 
 LOCATION = f"{BaseGalileoLogger.LOG_FILE_DIR}/{DEFAULT_PROJECT_ID}/{DEFAULT_RUN_ID}"
-STDOUT_HOME = f"{ConfigData.DEFAULT_GALILEO_CONFIG_DIR}/stdout"
-STDOUT_LOCATION = f"{STDOUT_HOME}/{DEFAULT_RUN_ID}"
+DQ_LOG_FILE_LOCATION = f"{DQ_LOG_FILE_HOME}/{DEFAULT_RUN_ID}"
 TEST_STORE_DIR = "TEST_STORE"
 TEST_PATH = f"{LOCATION}/{TEST_STORE_DIR}"
 SPLITS = ["training", "test"]
@@ -58,12 +56,12 @@ def cleanup_after_use() -> Generator:
             for split in SPLITS:
                 for subdir in SUBDIRS:
                     os.makedirs(f"{TEST_PATH}/{split}/{subdir}")
-        if not os.path.isdir(STDOUT_LOCATION):
-            os.makedirs(STDOUT_LOCATION)
+        if not os.path.isdir(DQ_LOG_FILE_LOCATION):
+            os.makedirs(DQ_LOG_FILE_LOCATION)
         yield
     finally:
         shutil.rmtree(BaseGalileoLogger.LOG_FILE_DIR)
-        shutil.rmtree(STDOUT_LOCATION)
+        shutil.rmtree(DQ_LOG_FILE_LOCATION)
         dataquality.get_model_logger().logger_config.reset()
 
 
@@ -72,12 +70,10 @@ def set_test_config(
     default_token: str = "sometoken",
     default_task_type: TaskType = TaskType.text_classification,
     default_api_url: str = DEFAULT_API_URL,
-    default_minio_url: str = DEFAULT_MINIO_URL,
 ) -> Callable:
     config.token = default_token
     config.task_type = default_task_type
     config.api_url = default_api_url
-    config.minio_url = default_minio_url
     config.current_run_id = DEFAULT_RUN_ID
     config.current_project_id = DEFAULT_PROJECT_ID
 
