@@ -382,8 +382,16 @@ def test_prob_only(set_test_config) -> None:
     assert not logger.prob_only(test_split_runs, "test", "0")
 
 
+@mock.patch.object(dataquality.clients.api.ApiClient, "get_presigned_url")
+@mock.patch.object(
+    dataquality.clients.objectstore.ObjectStore, "_upload_file_from_local"
+)
 def test_log_invalid_model_outputs(
-    cleanup_after_use: Callable, set_test_config: Callable, input_data: Callable
+    mock_upload_from_local: mock.MagicMock,
+    mock_presigned_url: mock.MagicMock,
+    cleanup_after_use: Callable,
+    set_test_config: Callable,
+    input_data: Callable,
 ) -> None:
     """Validate that we interrupt the main process if issues occur while logging"""
     dataquality.set_labels_for_run(["APPLE", "ORANGE"])
@@ -400,6 +408,8 @@ def test_log_invalid_model_outputs(
         "epoch": 0,
     }
     with pytest.raises(GalileoException) as e:
+        mock_presigned_url.return_value = "https://google.com"
+        mock_upload_from_local.return_value = None
         dataquality.log_model_outputs(**output_data)
         time.sleep(1)  # ensure the first one records a failure
         dataquality.log_model_outputs(**output_data)
@@ -408,8 +418,16 @@ def test_log_invalid_model_outputs(
     assert str(e.value).startswith("An issue occurred while logging model outputs.")
 
 
+@mock.patch.object(dataquality.clients.api.ApiClient, "get_presigned_url")
+@mock.patch.object(
+    dataquality.clients.objectstore.ObjectStore, "_upload_file_from_local"
+)
 def test_log_invalid_model_outputs_final_thread(
-    cleanup_after_use: Callable, set_test_config: Callable, input_data: Callable
+    mock_upload_from_local: mock.MagicMock,
+    mock_presigned_url: mock.MagicMock,
+    cleanup_after_use: Callable,
+    set_test_config: Callable,
+    input_data: Callable,
 ) -> None:
     """Validate that we error on finish if issues occur while logging"""
     assert dataquality.get_model_logger().logger_config.exception == ""
@@ -427,8 +445,10 @@ def test_log_invalid_model_outputs_final_thread(
         "epoch": 0,
     }
 
+    mock_presigned_url.return_value = "https://google.com"
     dataquality.log_model_outputs(**output_data)
     with pytest.raises(GalileoException) as e:
+        mock_upload_from_local.return_value = None
         dataquality.get_data_logger().upload()
 
     assert dataquality.get_model_logger().logger_config.exception != ""
@@ -460,7 +480,6 @@ def test_calls_noop() -> None:
     os.environ["GALILEO_DISABLED"] = "True"
     c = dataquality.core._config.set_config()
     assert c.api_url == "http://"
-    assert c.minio_url == ""
     with mock.patch("dataquality.core.log.log_data_samples") as mock_log:
         dataquality.log_data_samples(texts=["test"], labels=["1"], ids=[1])
         mock_log.assert_not_called()
